#
# spec file for package typesafe-config
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           typesafe-config
Version:        1.4.1
Release:        6.3
Summary:        Configuration library for JVM languages
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/typesafehub/config
Source0:        %{URL}/archive/v%{version}.tar.gz#/config-%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/com/typesafe/config/%{version}/config-%{version}.pom
Patch0:         fix-doc-lint.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildArch:      noarch
%if 0%{?rhel} >= 9
BuildRequires:  xmvn-tools
%endif

%description
Configuration library for JVM languages.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n config-%{version}
%patch -P 0 -p1

%build
pushd config
mkdir -p target/classes
javac -d target/classes \
  -source 8 \
  -target 8 \
  -g \
  -Xlint:unchecked \
  $(find src/main/java -name \*.java | xargs)
jar \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 17}%{!?pkg_vcmp:0}
  --date="$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)" \
%endif
  --create --file=target/config.jar -C target/classes .

%if ! 0%{?rhel} >= 9
mkdir -p target/api
javadoc -d target/api \
  -source 8 \
  -notimestamp \
  -group "Public API (version %{version})" "com.typesafe.config:com.typesafe.config.parser" \
  -group "Internal Implementation - Not ABI Stable" "com.typesafe.config.impl" \
  $(find src/main/java -name \*.java | xargs)
%endif

popd
cp %{SOURCE1} .
%{mvn_artifact} config-%{version}.pom config/target/config.jar

%install
%if 0%{?rhel}
%mvn_install
%else
# jar
install -d -m 755 %{buildroot}%{_javadir}
install -pm 644 config/target/config.jar %{buildroot}%{_javadir}/%{name}.jar
# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE1} %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar
%endif

%if ! 0%{?rhel} >= 9
#javadoc
mkdir -p %{buildroot}%{_javadocdir}
cp -a config/target/api %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}
%endif

%files -f .mfiles
%doc NEWS.md README.md
%license LICENSE-2.0.txt

%if ! 0%{?rhel} >= 9
%files javadoc
%license LICENSE-2.0.txt
%{_javadocdir}/*
%endif

%changelog
* Tue Sep 24 2024 Fridrich Strba <fstrba@suse.com>
- Use SOURCE_DATE_EPOCH for reproducible builds
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Apr 14 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Added build on Enterprise Linux 9.
* Tue Mar 29 2022 Michael Calmer <mc@suse.com>
- Added patch:
  * fix-doc-lint.patch
    + fix javadoc lint errors
* Tue Jul 27 2021 Fridrich Strba <fstrba@suse.com>
- Build with java-devel >= 1.8 since source/target levels 8 are
  requested
* Mon Apr 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.4.1:
  * Add a helper method for parsing only application overrides
  * Remove unmodifiable collection wrappers in ResolveContext
  * Added support for memory units which don't fit in a long when
    transformed to bytes
  * Inherit optional and getter evaluation
  * A few other bug fixes
- Update to 1.4.0:
  * application.conf variables can now override variables in
    reference.conf
  * Performance improvement through capacity hint for ArrayList
* Fri Apr 16 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.3.4:
  * It is now possible to override any configuration setting from
    environment variables
  * Added support for integer keys that are longer than Int
  * Missing exception now has a reference to the origin Config
  * Performance improvements to resolve()
  * Config file syntax is now resolved when parsing InputStream
  * It is now possible to use @Optional on keys that are reserved words
  * ValidationProblem is now serializable
- Update to 1.3.3:
  * Minor issue fix
- Update to 1.3.2:
  * Environment variables are now able to be resolved to lists in the
    same fashion as system properties.
  * Added getPeriod() which returns time units as java.time.Period.
    Currently supported periods are days, weeks, months and years.
  * ConfigResolveOptions now has appendResolver(...) which allows
    having custom behavior when unresolved substitutions are
    encountered during resolution.
  * Config Beans now support Set collection.
  * A few other small bugfixes.
- Update 1.3.1:
  * Added include required("foo") syntax to specify includes that fail
    if not present support for more kinds of property in
    ConfigBeanFactory:
    enumerations
    optional fields
    lists of beans
  * numbers can now start with a decimal (".33" vs. "0.33"), these
    are still parsed as strings but Config.getDouble() etc. will
    convert them to numbers a few other small bugfixes
* Fri Apr 16 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.3.0
  * 1.3.0 should be ABI-compatible with 1.2.x for most applications
  * Added Config.hasPathOrNull, Config.getIsNull and
    parser.ConfigDocument which supports simple load/edit/save on a
    config file.
  * Fixed obscure bug in converting to camel case when instantiating
    beans
  * Now built with Java 8 and requires Java 8
  * If you were relying on the order of key iteration in a config,
    note that Java 8 changed the iteration order for hashes and that
    includes Config and ConfigObject several correctness fixes to
    resolving substitutions.
  * ConfigBeanFactory will auto-fill a JavaBean from a Config
  * It is now possible to create a ConfigOrigin using
    ConfigOriginFactory and to modify origins on values using
    ConfigValue.withOrigin
  * Config.getMemorySize returns a ConfigMemorySize
  * Config.getDuration returns a java.time.Duration
  * The existing ConfigValueFactory.fromAnyRef and related methods
    now pass through a ConfigValue instead of throwing an exception
  * ConfigFactory.defaultApplication() returns the default Config
    used by ConfigFactory.load() in between defaultReference() and
    defaultOverrides(), leaving ConfigFactory.load() as a trivial
    convenience API that uses no internal magic.
  * Fix "allow unresolved" behavior for unresolved list elements
  * Class loaders are cached with a WeakReference to avoid leaks
  * Create valid output for values with multiline descriptions
- Update to 1.2.1
  * Fix resolving substitutions in include statements nested
    inside objects
  * When rendering an object to a string, sort the fields
  * Handle unresolved substitutions in value concatenations
  * Make ConfigOrigin.comments unmodifiable
  * When using '+=' or 'include' inside a list, throw an exception
    instead of generating a wrong result
  * When context class loader is unset throw a more helpful
    exception than NullPointerException
  * Ignore non-string values in a Properties object
* Fri Dec 21 2018 Fridrich Strba <fstrba@suse.com>
- Initial package
